Index: include/asterisk/manager.h
===================================================================
--- include/asterisk/manager.h	(revision 44595)
+++ include/asterisk/manager.h	(working copy)
@@ -60,6 +60,27 @@
 #define AST_MAX_MANHEADERS 80
 #define AST_MAX_MANHEADER_LEN 256
 
+/* Manager Helper Function */
+typedef int (*manager_hook_t)(int, const char *, char *); 
+
+struct manager_custom_hook {
+	/*! Identifier */
+	char *file;
+	/*! helper function */
+	manager_hook_t helper;
+	struct manager_custom_hook *next;
+};
+
+/*! Add a custom hook to be called when an event is fired */
+/*! \param hook struct manager_custom_hook object to add
+*/
+extern void add_manager_hook(struct manager_custom_hook *hook);
+
+/*! Delete a custom hook to be called when an event is fired */
+/*! \param hook struct manager_custom_hook object to delete
+*/
+extern void del_manager_hook(struct manager_custom_hook *hook);
+
 struct mansession;
 
 struct message {
Index: main/manager.c
===================================================================
--- main/manager.c	(revision 44595)
+++ main/manager.c	(working copy)
@@ -193,7 +193,40 @@
 
 static struct manager_action *first_action = NULL;
 AST_MUTEX_DEFINE_STATIC(actionlock);
+AST_MUTEX_DEFINE_STATIC(hooklock);
+ 
+static struct manager_custom_hook *manager_hooks = NULL;
 
+
+void add_manager_hook(struct manager_custom_hook *hook)
+{
+	ast_mutex_lock(&hooklock);
+	if (hook) {
+		hook->next = manager_hooks;
+		manager_hooks = hook;
+	}
+	ast_mutex_unlock(&hooklock);
+}
+
+void del_manager_hook(struct manager_custom_hook *hook)
+{
+	struct manager_custom_hook *hookp, *lasthook = NULL;
+
+	ast_mutex_lock(&hooklock);
+	for (hookp = manager_hooks; hookp ; hookp = hookp->next) {
+		if (hookp == hook) {
+			if (lasthook) {
+				lasthook->next = hookp->next;
+			} else {
+				manager_hooks = hookp->next;
+			}
+		}
+		lasthook = hookp;
+	}
+	ast_mutex_unlock(&hooklock);
+
+}
+
 /*! \brief Convert authority code to string with serveral options */
 static char *authority_to_str(int authority, char *res, int reslen)
 {
@@ -2211,6 +2244,7 @@
 {
 	struct mansession *s;
 	char auth[80];
+	char tmp[4096] = "";
 	va_list ap;
 	struct timeval now;
 	struct ast_dynamic_str *buf;
@@ -2251,6 +2285,24 @@
 	}
 	AST_LIST_UNLOCK(&sessions);
 
+	if (manager_hooks) {
+		struct manager_custom_hook *hookp;
+		ast_mutex_lock(&hooklock);
+		char *p;
+		int len;
+		snprintf(tmp, sizeof(tmp), "event: %s\r\nprivilege: %s\r\n", event, authority_to_str(category, tmp, sizeof(tmp)));
+		len = strlen(tmp);
+		p = tmp + len;
+		va_start(ap, fmt);
+		vsnprintf(p, sizeof(tmp) - len, fmt, ap);
+		va_end(ap);
+		for (hookp = manager_hooks ; hookp; hookp = hookp->next) {
+				hookp->helper(category, event, tmp);
+		}
+	
+		ast_mutex_unlock(&hooklock);
+	}
+
 	return 0;
 }
 
